.. heudiconv documentation master file, created by
   sphinx-quickstart on Mon Mar 25 15:42:31 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

Contents
--------

.. toctree::
   :maxdepth: 2

   installation
   changes
   usage
   heuristics
   tutorials
   api
